# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ContactArgs', 'Contact']

@pulumi.input_type
class ContactArgs:
    def __init__(__self__, *,
                 address1: pulumi.Input[_builtins.str],
                 city: pulumi.Input[_builtins.str],
                 country: pulumi.Input[_builtins.str],
                 email: pulumi.Input[_builtins.str],
                 first_name: pulumi.Input[_builtins.str],
                 last_name: pulumi.Input[_builtins.str],
                 phone: pulumi.Input[_builtins.str],
                 postal_code: pulumi.Input[_builtins.str],
                 state_province: pulumi.Input[_builtins.str],
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Contact resource.

        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        """
        pulumi.set(__self__, "address1", address1)
        pulumi.set(__self__, "city", city)
        pulumi.set(__self__, "country", country)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "first_name", first_name)
        pulumi.set(__self__, "last_name", last_name)
        pulumi.set(__self__, "phone", phone)
        pulumi.set(__self__, "postal_code", postal_code)
        pulumi.set(__self__, "state_province", state_province)
        if address2 is not None:
            pulumi.set(__self__, "address2", address2)
        if fax is not None:
            pulumi.set(__self__, "fax", fax)
        if job_title is not None:
            pulumi.set(__self__, "job_title", job_title)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if organization_name is not None:
            pulumi.set(__self__, "organization_name", organization_name)

    @_builtins.property
    @pulumi.getter
    def address1(self) -> pulumi.Input[_builtins.str]:
        """
        The primary address line (street address, building number, etc.).
        """
        return pulumi.get(self, "address1")

    @address1.setter
    def address1(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "address1", value)

    @_builtins.property
    @pulumi.getter
    def city(self) -> pulumi.Input[_builtins.str]:
        """
        The city where the contact is located.
        """
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "city", value)

    @_builtins.property
    @pulumi.getter
    def country(self) -> pulumi.Input[_builtins.str]:
        """
        The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "country", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Input[_builtins.str]:
        """
        The contact's email address.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Input[_builtins.str]:
        """
        The first name of the contact person.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "first_name", value)

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Input[_builtins.str]:
        """
        The last name of the contact person.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "last_name", value)

    @_builtins.property
    @pulumi.getter
    def phone(self) -> pulumi.Input[_builtins.str]:
        """
        The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "phone", value)

    @_builtins.property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> pulumi.Input[_builtins.str]:
        """
        The postal code, ZIP code, or equivalent for the contact's location.
        """
        return pulumi.get(self, "postal_code")

    @postal_code.setter
    def postal_code(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "postal_code", value)

    @_builtins.property
    @pulumi.getter(name="stateProvince")
    def state_province(self) -> pulumi.Input[_builtins.str]:
        """
        The state, province, or region where the contact is located.
        """
        return pulumi.get(self, "state_province")

    @state_province.setter
    def state_province(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "state_province", value)

    @_builtins.property
    @pulumi.getter
    def address2(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secondary address line (apartment, suite, floor, etc.).
        """
        return pulumi.get(self, "address2")

    @address2.setter
    def address2(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address2", value)

    @_builtins.property
    @pulumi.getter
    def fax(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        """
        return pulumi.get(self, "fax")

    @fax.setter
    def fax(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fax", value)

    @_builtins.property
    @pulumi.getter(name="jobTitle")
    def job_title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The job title or position of the contact person within the organization.
        """
        return pulumi.get(self, "job_title")

    @job_title.setter
    def job_title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_title", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A descriptive label for the contact to help identify it.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the organization or company associated with the contact.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_name", value)


@pulumi.input_type
class _ContactState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.int]] = None,
                 address1: Optional[pulumi.Input[_builtins.str]] = None,
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 city: Optional[pulumi.Input[_builtins.str]] = None,
                 country: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 fax_normalized: Optional[pulumi.Input[_builtins.str]] = None,
                 first_name: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 last_name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 phone: Optional[pulumi.Input[_builtins.str]] = None,
                 phone_normalized: Optional[pulumi.Input[_builtins.str]] = None,
                 postal_code: Optional[pulumi.Input[_builtins.str]] = None,
                 state_province: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Contact resources.

        :param pulumi.Input[_builtins.int] account_id: The account ID for the contact.
        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] created_at: Timestamp representing when this contact was created.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] fax_normalized: The fax number, normalized.
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] phone_normalized: The phone number, normalized.
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        :param pulumi.Input[_builtins.str] updated_at: Timestamp representing when this contact was updated.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if address1 is not None:
            pulumi.set(__self__, "address1", address1)
        if address2 is not None:
            pulumi.set(__self__, "address2", address2)
        if city is not None:
            pulumi.set(__self__, "city", city)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if fax is not None:
            pulumi.set(__self__, "fax", fax)
        if fax_normalized is not None:
            pulumi.set(__self__, "fax_normalized", fax_normalized)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if job_title is not None:
            pulumi.set(__self__, "job_title", job_title)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if organization_name is not None:
            pulumi.set(__self__, "organization_name", organization_name)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if phone_normalized is not None:
            pulumi.set(__self__, "phone_normalized", phone_normalized)
        if postal_code is not None:
            pulumi.set(__self__, "postal_code", postal_code)
        if state_province is not None:
            pulumi.set(__self__, "state_province", state_province)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The account ID for the contact.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def address1(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The primary address line (street address, building number, etc.).
        """
        return pulumi.get(self, "address1")

    @address1.setter
    def address1(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address1", value)

    @_builtins.property
    @pulumi.getter
    def address2(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secondary address line (apartment, suite, floor, etc.).
        """
        return pulumi.get(self, "address2")

    @address2.setter
    def address2(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address2", value)

    @_builtins.property
    @pulumi.getter
    def city(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The city where the contact is located.
        """
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "city", value)

    @_builtins.property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "country", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp representing when this contact was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's email address.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def fax(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        """
        return pulumi.get(self, "fax")

    @fax.setter
    def fax(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fax", value)

    @_builtins.property
    @pulumi.getter(name="faxNormalized")
    def fax_normalized(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fax number, normalized.
        """
        return pulumi.get(self, "fax_normalized")

    @fax_normalized.setter
    def fax_normalized(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fax_normalized", value)

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The first name of the contact person.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "first_name", value)

    @_builtins.property
    @pulumi.getter(name="jobTitle")
    def job_title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The job title or position of the contact person within the organization.
        """
        return pulumi.get(self, "job_title")

    @job_title.setter
    def job_title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "job_title", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A descriptive label for the contact to help identify it.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last name of the contact person.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_name", value)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the organization or company associated with the contact.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_name", value)

    @_builtins.property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "phone", value)

    @_builtins.property
    @pulumi.getter(name="phoneNormalized")
    def phone_normalized(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The phone number, normalized.
        """
        return pulumi.get(self, "phone_normalized")

    @phone_normalized.setter
    def phone_normalized(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "phone_normalized", value)

    @_builtins.property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The postal code, ZIP code, or equivalent for the contact's location.
        """
        return pulumi.get(self, "postal_code")

    @postal_code.setter
    def postal_code(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "postal_code", value)

    @_builtins.property
    @pulumi.getter(name="stateProvince")
    def state_province(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The state, province, or region where the contact is located.
        """
        return pulumi.get(self, "state_province")

    @state_province.setter
    def state_province(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state_province", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp representing when this contact was updated.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("dnsimple:index/contact:Contact")
class Contact(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address1: Optional[pulumi.Input[_builtins.str]] = None,
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 city: Optional[pulumi.Input[_builtins.str]] = None,
                 country: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 first_name: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 last_name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 phone: Optional[pulumi.Input[_builtins.str]] = None,
                 postal_code: Optional[pulumi.Input[_builtins.str]] = None,
                 state_province: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a DNSimple contact resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example = dnsimple.Contact("example",
            label="Main Contact",
            first_name="John",
            last_name="Doe",
            organization_name="Example Inc",
            job_title="Manager",
            address1="123 Main Street",
            address2="Suite 100",
            city="San Francisco",
            state_province="California",
            postal_code="94105",
            country="US",
            phone="+1.4155551234",
            fax="+1.4155555678",
            email="john@example.com")
        ```

        ## Import

        DNSimple contacts can be imported using their numeric ID.

        ```sh
        $ pulumi import dnsimple:index/contact:Contact example 5678
        ```

        The contact ID can be found within the [DNSimple Contacts API](https://developer.dnsimple.com/v2/contacts/#listContacts). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContactArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNSimple contact resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        example = dnsimple.Contact("example",
            label="Main Contact",
            first_name="John",
            last_name="Doe",
            organization_name="Example Inc",
            job_title="Manager",
            address1="123 Main Street",
            address2="Suite 100",
            city="San Francisco",
            state_province="California",
            postal_code="94105",
            country="US",
            phone="+1.4155551234",
            fax="+1.4155555678",
            email="john@example.com")
        ```

        ## Import

        DNSimple contacts can be imported using their numeric ID.

        ```sh
        $ pulumi import dnsimple:index/contact:Contact example 5678
        ```

        The contact ID can be found within the [DNSimple Contacts API](https://developer.dnsimple.com/v2/contacts/#listContacts). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.


        :param str resource_name: The name of the resource.
        :param ContactArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContactArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address1: Optional[pulumi.Input[_builtins.str]] = None,
                 address2: Optional[pulumi.Input[_builtins.str]] = None,
                 city: Optional[pulumi.Input[_builtins.str]] = None,
                 country: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 fax: Optional[pulumi.Input[_builtins.str]] = None,
                 first_name: Optional[pulumi.Input[_builtins.str]] = None,
                 job_title: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 last_name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 phone: Optional[pulumi.Input[_builtins.str]] = None,
                 postal_code: Optional[pulumi.Input[_builtins.str]] = None,
                 state_province: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContactArgs.__new__(ContactArgs)

            if address1 is None and not opts.urn:
                raise TypeError("Missing required property 'address1'")
            __props__.__dict__["address1"] = address1
            __props__.__dict__["address2"] = address2
            if city is None and not opts.urn:
                raise TypeError("Missing required property 'city'")
            __props__.__dict__["city"] = city
            if country is None and not opts.urn:
                raise TypeError("Missing required property 'country'")
            __props__.__dict__["country"] = country
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["fax"] = fax
            if first_name is None and not opts.urn:
                raise TypeError("Missing required property 'first_name'")
            __props__.__dict__["first_name"] = first_name
            __props__.__dict__["job_title"] = job_title
            __props__.__dict__["label"] = label
            if last_name is None and not opts.urn:
                raise TypeError("Missing required property 'last_name'")
            __props__.__dict__["last_name"] = last_name
            __props__.__dict__["organization_name"] = organization_name
            if phone is None and not opts.urn:
                raise TypeError("Missing required property 'phone'")
            __props__.__dict__["phone"] = phone
            if postal_code is None and not opts.urn:
                raise TypeError("Missing required property 'postal_code'")
            __props__.__dict__["postal_code"] = postal_code
            if state_province is None and not opts.urn:
                raise TypeError("Missing required property 'state_province'")
            __props__.__dict__["state_province"] = state_province
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["fax_normalized"] = None
            __props__.__dict__["phone_normalized"] = None
            __props__.__dict__["updated_at"] = None
        super(Contact, __self__).__init__(
            'dnsimple:index/contact:Contact',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.int]] = None,
            address1: Optional[pulumi.Input[_builtins.str]] = None,
            address2: Optional[pulumi.Input[_builtins.str]] = None,
            city: Optional[pulumi.Input[_builtins.str]] = None,
            country: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            fax: Optional[pulumi.Input[_builtins.str]] = None,
            fax_normalized: Optional[pulumi.Input[_builtins.str]] = None,
            first_name: Optional[pulumi.Input[_builtins.str]] = None,
            job_title: Optional[pulumi.Input[_builtins.str]] = None,
            label: Optional[pulumi.Input[_builtins.str]] = None,
            last_name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_name: Optional[pulumi.Input[_builtins.str]] = None,
            phone: Optional[pulumi.Input[_builtins.str]] = None,
            phone_normalized: Optional[pulumi.Input[_builtins.str]] = None,
            postal_code: Optional[pulumi.Input[_builtins.str]] = None,
            state_province: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'Contact':
        """
        Get an existing Contact resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] account_id: The account ID for the contact.
        :param pulumi.Input[_builtins.str] address1: The primary address line (street address, building number, etc.).
        :param pulumi.Input[_builtins.str] address2: The secondary address line (apartment, suite, floor, etc.).
        :param pulumi.Input[_builtins.str] city: The city where the contact is located.
        :param pulumi.Input[_builtins.str] country: The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        :param pulumi.Input[_builtins.str] created_at: Timestamp representing when this contact was created.
        :param pulumi.Input[_builtins.str] email: The contact's email address.
        :param pulumi.Input[_builtins.str] fax: The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        :param pulumi.Input[_builtins.str] fax_normalized: The fax number, normalized.
        :param pulumi.Input[_builtins.str] first_name: The first name of the contact person.
        :param pulumi.Input[_builtins.str] job_title: The job title or position of the contact person within the organization.
        :param pulumi.Input[_builtins.str] label: A descriptive label for the contact to help identify it.
        :param pulumi.Input[_builtins.str] last_name: The last name of the contact person.
        :param pulumi.Input[_builtins.str] organization_name: The name of the organization or company associated with the contact.
        :param pulumi.Input[_builtins.str] phone: The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        :param pulumi.Input[_builtins.str] phone_normalized: The phone number, normalized.
        :param pulumi.Input[_builtins.str] postal_code: The postal code, ZIP code, or equivalent for the contact's location.
        :param pulumi.Input[_builtins.str] state_province: The state, province, or region where the contact is located.
        :param pulumi.Input[_builtins.str] updated_at: Timestamp representing when this contact was updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContactState.__new__(_ContactState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["address1"] = address1
        __props__.__dict__["address2"] = address2
        __props__.__dict__["city"] = city
        __props__.__dict__["country"] = country
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["email"] = email
        __props__.__dict__["fax"] = fax
        __props__.__dict__["fax_normalized"] = fax_normalized
        __props__.__dict__["first_name"] = first_name
        __props__.__dict__["job_title"] = job_title
        __props__.__dict__["label"] = label
        __props__.__dict__["last_name"] = last_name
        __props__.__dict__["organization_name"] = organization_name
        __props__.__dict__["phone"] = phone
        __props__.__dict__["phone_normalized"] = phone_normalized
        __props__.__dict__["postal_code"] = postal_code
        __props__.__dict__["state_province"] = state_province
        __props__.__dict__["updated_at"] = updated_at
        return Contact(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.int]:
        """
        The account ID for the contact.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def address1(self) -> pulumi.Output[_builtins.str]:
        """
        The primary address line (street address, building number, etc.).
        """
        return pulumi.get(self, "address1")

    @_builtins.property
    @pulumi.getter
    def address2(self) -> pulumi.Output[_builtins.str]:
        """
        The secondary address line (apartment, suite, floor, etc.).
        """
        return pulumi.get(self, "address2")

    @_builtins.property
    @pulumi.getter
    def city(self) -> pulumi.Output[_builtins.str]:
        """
        The city where the contact is located.
        """
        return pulumi.get(self, "city")

    @_builtins.property
    @pulumi.getter
    def country(self) -> pulumi.Output[_builtins.str]:
        """
        The two-letter ISO country code (e.g., "US", "CA", "IT") for the contact's location.
        """
        return pulumi.get(self, "country")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp representing when this contact was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        The contact's email address.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def fax(self) -> pulumi.Output[_builtins.str]:
        """
        The contact's fax number. Use international format with country code (e.g., "+1.8491234567" for US numbers).
        """
        return pulumi.get(self, "fax")

    @_builtins.property
    @pulumi.getter(name="faxNormalized")
    def fax_normalized(self) -> pulumi.Output[_builtins.str]:
        """
        The fax number, normalized.
        """
        return pulumi.get(self, "fax_normalized")

    @_builtins.property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Output[_builtins.str]:
        """
        The first name of the contact person.
        """
        return pulumi.get(self, "first_name")

    @_builtins.property
    @pulumi.getter(name="jobTitle")
    def job_title(self) -> pulumi.Output[_builtins.str]:
        """
        The job title or position of the contact person within the organization.
        """
        return pulumi.get(self, "job_title")

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Output[_builtins.str]:
        """
        A descriptive label for the contact to help identify it.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Output[_builtins.str]:
        """
        The last name of the contact person.
        """
        return pulumi.get(self, "last_name")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the organization or company associated with the contact.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter
    def phone(self) -> pulumi.Output[_builtins.str]:
        """
        The contact's phone number. Use international format with country code (e.g., "+1.4012345678" for US numbers).
        """
        return pulumi.get(self, "phone")

    @_builtins.property
    @pulumi.getter(name="phoneNormalized")
    def phone_normalized(self) -> pulumi.Output[_builtins.str]:
        """
        The phone number, normalized.
        """
        return pulumi.get(self, "phone_normalized")

    @_builtins.property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> pulumi.Output[_builtins.str]:
        """
        The postal code, ZIP code, or equivalent for the contact's location.
        """
        return pulumi.get(self, "postal_code")

    @_builtins.property
    @pulumi.getter(name="stateProvince")
    def state_province(self) -> pulumi.Output[_builtins.str]:
        """
        The state, province, or region where the contact is located.
        """
        return pulumi.get(self, "state_province")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp representing when this contact was updated.
        """
        return pulumi.get(self, "updated_at")

