# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

account: Optional[str]
"""
The account for API operations.
"""

debugTransportFile: Optional[str]
"""
File path to enable HTTP request/response debugging. When set, all HTTP requests and responses will be logged to this file.
"""

prefetch: Optional[bool]
"""
Flag to enable the prefetch of zone records.
"""

sandbox: Optional[bool]
"""
Flag to enable the sandbox API.
"""

token: Optional[str]
"""
The API v2 token for API operations.
"""

userAgent: Optional[str]
"""
Custom string to append to the user agent used for sending HTTP requests to the API.
"""

