# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import pulumi
from enum import Enum

__all__ = [
    'RecordTypes',
]


@pulumi.type_token("dnsimple:index:RecordTypes")
class RecordTypes(_builtins.str, Enum):
    """
    DNS Record types.
    """
    A = "A"
    AAAA = "AAAA"
    ALIAS = "ALIAS"
    CAA = "CAA"
    CNAME = "CNAME"
    HINFO = "HINFO"
    MX = "MX"
    NAPTR = "NAPTR"
    NS = "NS"
    POOL = "POOL"
    PTR = "PTR"
    SPF = "SPF"
    SRV = "SRV"
    SSHFP = "SSHFP"
    TXT = "TXT"
    URL = "URL"
